# reaction

* `cd example && docker-compose up --force-recreate --build`
* RabbitMQ web ui: http://127.0.0.1:15672/#/
  * user: admin
  * password: j8XfG9ZDT5ZZrWTzw62q
* Docs: http://127.0.0.1:8000/docs#/
* Redoc: http://127.0.0.1:8000/redoc
